@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpaceViewTypes|
-|''Version''|0.5.3|
+|''Version''|0.5.4|
 |''Status''|@@beta@@|
 |''Description''|Provides TiddlySpace specific view types|
 |''Author''|Jon Robson|
@@ -57,7 +57,7 @@ config.macros.view.views.replyLink = function(value, place, params, wikifier,
 config.macros.view.views.spaceLink = function(value, place, params, wikifier,
 		paramString, tiddler) {
 		var spaceName = tiddlyspace.resolveSpaceName(value);
-		var isBag = value === spaceName ? true : false;
+		var isBag = params[0] == "server.bag" && value === spaceName ? true : false;
 		var args = paramString.parseParams("anon")[0];
 		var titleField = args.anon[2];
 		var labelField = args.labelField ? args.labelField[0] : false;
